package com.hw.ems.base.mapper;



import com.hw.ems.base.domain.CbsMonitorReport;

import java.util.List;

/**
 * CBS抄报Mapper接口
 *
 * @author YinQ
 * @date 2023-10-20
 */
public interface CbsMonitorReportMapper
{
    /**
     * 查询CBS抄报
     *
     * @param objId CBS抄报主键
     * @return CBS抄报
     */
    public CbsMonitorReport selectCbsMonitorReportByObjId(Long objId);

    /**
     * 查询CBS抄报列表
     *
     * @param cbsMonitorReport CBS抄报
     * @return CBS抄报集合
     */
    public List<CbsMonitorReport> selectCbsMonitorReportList(CbsMonitorReport cbsMonitorReport);

    /**
     * 新增CBS抄报
     *
     * @param cbsMonitorReport CBS抄报
     * @return 结果
     */
    public int insertCbsMonitorReport(CbsMonitorReport cbsMonitorReport);

    /**
     * 修改CBS抄报
     *
     * @param cbsMonitorReport CBS抄报
     * @return 结果
     */
    public int updateCbsMonitorReport(CbsMonitorReport cbsMonitorReport);

    /**
     * 删除CBS抄报
     *
     * @param objId CBS抄报主键
     * @return 结果
     */
    public int deleteCbsMonitorReportByObjId(Long objId);

    /**
     * 批量删除CBS抄报
     *
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCbsMonitorReportByObjIds(Long[] objIds);


//    /**
//     * 查询电实时数据
//     *
//     * @param emsApiVo CBS抄报
//     * @return CBS抄报集合
//     */
//    public List<CbsMonitorReport> selectRealTimeMonitorList(EmsApiVo emsApiVo);

    /**
     * 查询上次CBS抄表数据
     *
     * @param cbsMonitorReport CBS抄报主键
     * @return CBS抄报
     */
    public CbsMonitorReport selectLastTimeCbsMonitorReport(CbsMonitorReport cbsMonitorReport);

}
